@@ -2,19 +2,11 @@ import pytest
 
 from six import with_metaclass
 
+from basicco import BaseMeta
 from basicco.explicit_hash import ExplicitHashMeta
 
 
-@pytest.fixture()
-def meta(pytestconfig):
-    metacls = pytestconfig.getoption("metacls")
-    if metacls:
-        meta_module, meta_name = metacls.split("|")
-        return getattr(__import__(meta_module, fromlist=[meta_name]), meta_name)
-    else:
-        return ExplicitHashMeta
-
-
+@pytest.mark.parametrize("meta", (ExplicitHashMeta, BaseMeta))
 def test_force_explicit_hash_declaration(meta):
     class Class(with_metaclass(meta, object)):
         pass
