@@ -2,20 +2,12 @@ import pytest
 
 from six import with_metaclass
 
+from basicco import BaseMeta
 from basicco.namespaced import NamespacedMeta
 from basicco.utils.namespace import Namespace
 
 
-@pytest.fixture()
-def meta(pytestconfig):
-    metacls = pytestconfig.getoption("metacls")
-    if metacls:
-        meta_module, meta_name = metacls.split("|")
-        return getattr(__import__(meta_module, fromlist=[meta_name]), meta_name)
-    else:
-        return NamespacedMeta
-
-
+@pytest.mark.parametrize("meta", (NamespacedMeta, BaseMeta))
 def test_private_namespace(meta):
     class Class(with_metaclass(meta, object)):
         pass
